@@ -13,51 +13,28 @@
 #include <cstdlib>
 #include <memory>
 
+#include "capi_test_utils.h"
+
 namespace tut {
 //
 // Test Group
 //
 
 // Common data used in test cases.
-struct test_capigeospreparedgeometry_data {
-    GEOSGeometry* geom1_;
-    GEOSGeometry* geom2_;
-
+struct test_capigeospreparedgeometry_data : public capitest::utility {
     const GEOSPreparedGeometry* prepGeom1_;
     const GEOSPreparedGeometry* prepGeom2_;
 
-
-
-    static void
-    notice(const char* fmt, ...)
-    {
-        std::fprintf(stdout, "NOTICE: ");
-
-        va_list ap;
-        va_start(ap, fmt);
-        std::vfprintf(stdout, fmt, ap);
-        va_end(ap);
-
-        std::fprintf(stdout, "\n");
-    }
-
     test_capigeospreparedgeometry_data()
-        : geom1_(nullptr), geom2_(nullptr), prepGeom1_(nullptr), prepGeom2_(nullptr)
-    {
-        initGEOS(notice, notice);
-    }
+        : prepGeom1_(nullptr), prepGeom2_(nullptr)
+    {}
 
     ~test_capigeospreparedgeometry_data()
     {
-        GEOSGeom_destroy(geom1_);
-        GEOSGeom_destroy(geom2_);
         GEOSPreparedGeom_destroy(prepGeom1_);
         GEOSPreparedGeom_destroy(prepGeom2_);
-        geom1_ = nullptr;
-        geom2_ = nullptr;
         prepGeom1_ = nullptr;
         prepGeom2_ = nullptr;
-        finishGEOS();
     }
 
 };
@@ -179,7 +156,7 @@ void object::test<6>
 }
 
 // Test PreparedIntersects: point on segment with FLOAT PM
-// X coordinate of 3rd and 4th vertises of the line are not
+// X coordinate of 3rd and 4th vertices of the line are not
 // float-point exact with X coordinate of the point.
 // The X values differ after 14th decimal place:
 // POINT (-23.1094689600055080 50.5195368635957180)
@@ -276,7 +253,7 @@ template<>
 void object::test<10>
 ()
 {
-    // Coincident vertives of both polygons at
+    // Coincident vertices of both polygons at
     // -700.67089999181 93743.4218587986, -713.450135807349 93754.1677576647,
     std::string const
     outer("01030000800100000009000000af9dd0005ee585c0f802efbff6e2f6400000000000000000955acde0994b86c039a922afa2e3f64000000000000000002af6fb4f5d1887c07adb1c4071e3f6400000000000000000e5962b388d4f87c0bd3aeda7bae2f640000000000000000087c61344030887c07d585e6ff6e1f6400000000000000000fc8a31b5166186c0230588b20ae1f640000000000000000034733daf050186c0ed9f3ac98ae1f6400000000000000000f190aef659b385c0df2876538ce2f6400000000000000000af9dd0005ee585c0f802efbff6e2f6400000000000000000");
@@ -339,7 +316,7 @@ template<>
 void object::test<11>
 ()
 {
-    // Coincident vertext at -753.167968418005 93709.4279185742
+    // Coincident vertex at -753.167968418005 93709.4279185742
     //POLYGON ((-753.167968418005 93754.0955183194,-816.392328351464 93754.0955183194,-816.392328351464 93709.4279185742,-753.167968418005 93709.4279185742,-753.167968418005 93754.0955183194))
     std::string const
     outer("01030000800100000005000000bd70d3ff578987c09e373e87a1e3f6400000000000000000a9f60b7d238389c09e373e87a1e3f6400000000000000000a9f60b7d238389c09625c1d8d6e0f6400000000000000000bd70d3ff578987c09625c1d8d6e0f6400000000000000000bd70d3ff578987c09e373e87a1e3f6400000000000000000");
@@ -393,5 +370,40 @@ void object::test<11>
         ensure_equals(ret, 0);
     }
 }
+
+// Test PreparedIntersects with Point EMPTY
+template<>
+template<>
+void object::test<12>
+()
+{
+    geom1_ = GEOSGeomFromWKT("POLYGON((0 0, 0 1, 1 1, 1 0, 0 0))");
+    geom2_ = GEOSGeomFromWKT("POINT EMPTY");
+    prepGeom1_ = GEOSPrepare(geom1_);
+
+    ensure(nullptr != prepGeom1_);
+    ensure(nullptr != geom2_);
+
+    int ret = GEOSPreparedIntersects(prepGeom1_, geom2_);
+    ensure_equals(ret, 0);
+}
+
+// Test PreparedCovers with Point EMPTY
+template<>
+template<>
+void object::test<13>
+()
+{
+    geom1_ = GEOSGeomFromWKT("POLYGON((0 0, 0 1, 1 1, 1 0, 0 0))");
+    geom2_ = GEOSGeomFromWKT("POINT EMPTY");
+    prepGeom1_ = GEOSPrepare(geom1_);
+
+    ensure(nullptr != prepGeom1_);
+    ensure(nullptr != geom2_);
+
+    int ret = GEOSPreparedCovers(prepGeom1_, geom2_);
+    ensure_equals(ret, 0);
+}
+
 } // namespace tut
 
